@@ -5,8 +5,14 @@ from asyncio import Semaphore
 
 class ApplicationService(object):
     """
-    An application service.
-    Extend this to add your own dependencies.
+    The application service base class.
+
+    :param db_service: The db service.
+    :param max_concurrent_actions: Maximum number of
+        actions to allow the application service to run concurrently,
+        defaults to 40. This should be adjusted according to the size of your
+        database's connection pool so that it's not exceeded when there's
+        lots of traffic.
     """
     def __init__(
         self,
@@ -20,8 +26,8 @@ class ApplicationService(object):
         job_adapter,
         log_service,
         scheduler_adapter,
-        max_concurrent_actions,
-        loop,
+        max_concurrent_actions=40,
+        loop=None,
     ):
         super().__init__()
 
@@ -55,8 +61,8 @@ class ApplicationService(object):
         ]
 
         # Vars
+        self.loop = loop if loop else asyncio.get_event_loop()
         self.max_concurrent_actions = max_concurrent_actions
-        self.loop = loop
 
         # Actions
         self._create_action_sem()
@@ -74,7 +80,7 @@ class ApplicationService(object):
 
     async def start(self):
         """
-        Starts the service.
+        Starts the application service.
         """
         self.log_service.info("Starting application service.")
 
@@ -89,7 +95,7 @@ class ApplicationService(object):
 
     async def stop(self):
         """
-        Stops the service.
+        Stops the application service.
         """
         self.log_service.info("Stopping application service.")
 
@@ -100,7 +106,7 @@ class ApplicationService(object):
         await self._stop_domain_services()
         await self._stop_infrastructure_services()
 
-        self.log_service.info("Application service stopped.")
+        self.log_service.info("Stopping application service.")
 
     async def _start_domain_publisher(self):
         """
